/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include <config.h>
#include <QString>
#include "PluginServices.h"
#include "CubeTestWidget.h"

using namespace advisor;

extern cubepluginapi::PluginServices* advisor_services;


CubeTestWidget::CubeTestWidget( PerformanceTest* _t )
{
    test = _t;
    if ( test->isNormalized() )
    {
        value = new QProgressBar();
        value->setMinimum( 0 );
        value->setMaximum( 100 );
        value->setAttribute( Qt::WA_Hover );
    }
    else
    {
        value = NULL;
    }


    name       = new QLabel( QString::fromStdString( test->name() ) );
    value_text = new QLabel( "" );
    value_text->setAttribute( Qt::WA_Hover );
    value_text->setWordWrap( true );

    value_as_number = new QLabel( "" );
    value_as_number->setAttribute( Qt::WA_Hover );
    value_as_number->setWordWrap( true );


    name->setEnabled( test->isActive() );
    if ( value != NULL )
    {
        value->setEnabled( test->isActive() );
    }
    value_text->setEnabled( test->isActive() );
    value_as_number->setEnabled( test->isActive() );

    if ( value != NULL )
    {
        value->installEventFilter( this );
    }
    value_text->installEventFilter( this );
    value_as_number->installEventFilter( this );
}


void
CubeTestWidget::updateCalculation()
{
    if (calculated)
        calculating();
    else
        apply();
}


void
CubeTestWidget::calculating( )
{
    if ( test->isActive() )
    {
        value_text->setText( tr( "calculating..." ) );
        value_as_number->setText( tr( "" ) );
        if ( value != NULL )
        {
            value->setValue( 0 );
        }
    }
}


void
CubeTestWidget::apply()
{
    if ( test->isActive() )
    {
        if ( value != NULL )
        {
            value->setEnabled( false );
        }
        value_text->setEnabled( false );
        value_as_number->setEnabled( false );

        if ( value != NULL )
        {
            value->setEnabled( true );
        }
        value_text->setEnabled( true );
        value_as_number->setEnabled( true );
        double v = ( test->isPercent() ) ? test->value() : ( test->value() / ( test->getMaximum() - test->getMinimum() ) );

        QColor vc_reg( 255 * ( 1 - v ), ( v ) * 255, 0, 255 );
        QColor vc_irreg( 255 * ( v ), ( 1 - v ) * 255, 0, 255 );
        QColor vc;
        if ( test->isRegular() )
        {
            vc = vc_reg;
        }
        else
        {
            vc = vc_irreg;
        }
        if ( value != NULL )
        {
            value->setStyleSheet( QString( "QProgressBar::chunk {background: %1; }" ).arg( vc.name() ) );
            value_text->setStyleSheet( QString( "QLabel {color: %1; }" ).arg( vc.name() ) );
            value->setValue( v *  100 );
        }

        QPair<QString, QString> value_unit = advisor_services->formatNumberAndUnit( test->value(),
                                                                                    test->units(),
                                                                                    cubegui::FORMAT_TREES,
                                                                                    false );
        value_as_number->setText( value_unit.first + " " + value_unit.second );



        value_text->setText( getValueText( v ) );
        value_text->setWordWrap( true );
        comment = QString::fromStdString( test->comment() );
    }
    else
    {
        if ( value != NULL )
        {
            value->setValue( 0 );
        }
    }
}

QString
CubeTestWidget::getValueText( double v )
{
    if ( !test->isNormalized() )
    {
        return tr( "Value" );
    }
    int range = ( test->isRegular() ) ? v * 5. : ( 1 - v ) * 5;
    switch ( range )
    {
        case 0:
            return tr( "Very poor" );
        case 1:
            return tr( "Poor" );
        case 2:
            return tr( "Fair" );
        case 3:
            return tr( "Good" );
        case 4:
            return tr( "Very good" );
        case 5:
            return tr( "Excellent" );
    }
    return tr( "" );
}
