/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include <config.h>

#include "CachePerformanceTest.h"

using namespace advisor;

CachePerformanceTest::CachePerformanceTest( L1CacheUtilizationPerformanceTest* _l1_utilization,
                                            L2CacheUtilizationPerformanceTest* _l2_utilization,
                                            L3CacheUtilizationPerformanceTest* _l3_utilization ) : PerformanceTest( NULL )
{
    l3_utilization = _l3_utilization;
    l2_utilization = _l2_utilization;
    l1_utilization = _l1_utilization;

    setName( tr( "Cache Performance Overall" ).toUtf8().data() );
    setWeight( 0.2 );   // need to be adjusted
}

void
CachePerformanceTest::calculateOverall()
{
    l3_utilization_weight = l3_utilization->isActive() ? l3_utilization->weight() : 0.;
    l2_utilization_weight = l2_utilization->isActive() ? l2_utilization->weight() : 0;
    l1_utilization_weight = l1_utilization->isActive() ? l1_utilization->weight() : 0;


    double l3_utilization_value = l3_utilization->value();
    double l2_utilization_value = l2_utilization->value();
    double l1_utilization_value = l1_utilization->value();


    double wsum = ( l3_utilization_weight * l3_utilization_value +
                    l2_utilization_weight * l2_utilization_value +
                    l1_utilization_weight * l1_utilization_value
                    );

    double norm = ( l3_utilization_weight +
                    l2_utilization_weight +
                    l1_utilization_weight
                    );
    setValue( wsum / norm );
}


const std::string&
CachePerformanceTest::getCommentText() const
{
    return no_comment;
}

// ------ overview tests ---------

bool
CachePerformanceTest::isActive() const
{
    return l1_utilization->isActive() || l2_utilization->isActive() || l3_utilization->isActive();
};

bool
CachePerformanceTest::isIssue() const
{
    return false;
};
