/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include <config.h>

#include "L1CacheUtilizationPerformanceTest.h"

using namespace advisor;

std::string L1CacheUtilizationPerformanceTest::l1_not_measured = QObject::tr(
    "PAPI metrics for L1 Cache utilizatio haven't been measured" ).toStdString();



L1CacheUtilizationPerformanceTest::L1CacheUtilizationPerformanceTest( cube::CubeProxy* cube ) : PerformanceTest( cube )
{
    setName( tr( "L1 Cache utilization" ).toUtf8().data() );
    setWeight( 0.2 );   // need to be adjusted
    l1_utilization = cube->getMetric( "l1_data_cache_utilization" );
    if ( l1_utilization == NULL )
    {
        l1_utilization = cube->getMetric( "l1_total_cache_utilization" );
        if ( l1_utilization == NULL )
        {
            setWeight( 0.2 );
            setValue( 0. );
            return;
        }
    }
    cube::list_of_metrics      lmetrics;
    cube::list_of_sysresources lsysres = getRootsOfSystemTree();
    cube::metric_pair          metric;
    metric.first  = l1_utilization;
    metric.second = cube::CUBE_CALCULATE_INCLUSIVE;
    lmetrics.push_back( metric );
    cube->getCallpathTreeValues( lmetrics,
                                 lsysres,
                                 inclusive_values,
                                 exclusive_values );
}

void
L1CacheUtilizationPerformanceTest::applyCnode( const cube::Cnode* cnode, const cube::CalculationFlavour cnf  )
{
    if ( l1_utilization == NULL )
    {
        return;
    }
    double l1_utilization_value = ( cnf == cube::CUBE_CALCULATE_INCLUSIVE ) ?
                                  inclusive_values[ cnode->get_id() ]->getDouble() :
                                  exclusive_values[ cnode->get_id() ]->getDouble();
    setValue( l1_utilization_value );
}

void
L1CacheUtilizationPerformanceTest::applyCnode( const cube::list_of_cnodes& cnodes  )
{
    if ( l1_utilization == NULL )
    {
        return;
    }

    cube::value_container      inclusive_values;
    cube::value_container      exclusive_values;
    cube::list_of_sysresources lsysres = getRootsOfSystemTree();
    cube::IdIndexMap           metric_id_indices;
    cube->getMetricSubtreeValues( cnodes,
                                  lsysres,
                                  *l1_utilization,
                                  1,
                                  metric_id_indices,
                                  &inclusive_values,
                                  &exclusive_values );
    double l1_utilization_value = inclusive_values[ 0 ]->getDouble();
    setValue( l1_utilization_value );
}

const std::string&
L1CacheUtilizationPerformanceTest::getCommentText() const
{
    if ( l1_utilization == NULL )
    {
        return l1_not_measured;
    }
    else
    {
        return no_comment;
    }
}


// ------ overview tests ---------

bool
L1CacheUtilizationPerformanceTest::isActive() const
{
    return l1_utilization != NULL;
};

bool
L1CacheUtilizationPerformanceTest::isIssue() const
{
    return false;
};
