/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#ifndef OVERVIEW_PERFORMANCE_ANALYSIS_H
#define OVERVIEW_PERFORMANCE_ANALYSIS_H

#include <string>
#include <QObject>
#include <QToolBar>
#include "Cube.h"


#include "PerformanceAnalysis.h"
#include "PerformanceTest.h"
#include "OverallPerformanceTest.h"
#include "OverallComputationPerformanceTest.h"
#include "OverallManagementPerformanceTest.h"
#include "AlgMgmtTest.h"
#include "CommunicationTest.h"
#include "GPUOverheadTest.h"
#include "IOOverheadTest.h"
#include "NonComputationLoadBalanceTest.h"
#include "ComputationLoadBalanceTest.h"




namespace advisor
{
class OverviewPerformanceAnalysis : public PerformanceAnalysis
{
    Q_OBJECT
private:
    QString NON_COMP_LB_ISSUE;
    QString COMP_LB_ISSUE;
    QString ALG_MGM_ISSUE;
    QString COMMUNICATION_ISSUE;
protected:


    OverallPerformanceTest*            overall;
    OverallComputationPerformanceTest* computation_overall;
    OverallManagementPerformanceTest*  management_overall;
    AlgMgmtTest*                       alg_mgm;
    CommunicationTest*                 communication;
    GPUOverheadTest*                   gpu_overhead;
    IOOverheadTest*                    io_overhead;
    NonComputationLoadBalanceTest*     non_computation_load_balance;
    ComputationLoadBalanceTest*        computation_load_balance;

public:
    OverviewPerformanceAnalysis( cube::CubeProxy* _cube );

    virtual
    ~OverviewPerformanceAnalysis();


    inline
    const
    std::string
    name() const
    {
        return "Overview";
    }


    virtual
    QWidget*
    getToolBar()
    {
        return new QWidget();
    }


    virtual
    QList<AdvisorAdvice>
    getCandidates( const QList<cubegui::TreeItem*>& );


    virtual
    QList<PerformanceTest*>
    getPerformanceTests();

    virtual
    QString
    getAnchorHowToMeasure();

// ------ overview tests ---------

    virtual
    bool
    isActive() const;
};
};

#endif // ADVISER_RATING_WIDGET_H
