/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2018                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#ifndef OVERALL_COMPUTATION_PERFORMANCE_TEST_H
#define OVERALL_COMPUTATION_PERFORMANCE_TEST_H

#include <string>

#include "CachePerformanceTest.h"
#include "ComputationLoadBalanceTest.h"
#include "PerformanceTest.h"
#include "VectorizationTest.h"
#include "BranchPredictionPerformanceTest.h"


namespace advisor
{
class OverallComputationPerformanceTest : public PerformanceTest
{
private:
    ComputationLoadBalanceTest* comp_load_balance;

    double comp_load_balance_weight;


protected:

    inline
    void
    applyCnode( const cube::list_of_cnodes& cnodes   )
    {
        ( void )cnodes;
        calculateOverall();
    }

    inline
    void
    applyCnode( const cube::Cnode*             cnode,
                const cube::CalculationFlavour cnf = cube::CUBE_CALCULATE_INCLUSIVE  )
    {
        ( void )cnode;
        ( void )cnf;
        calculateOverall();
    }

    void
    calculateOverall();

    virtual
    const std::string&
    getCommentText() const;

    inline
    const
    QString
    getHelpUrl()
    {
        return ( isActive() ) ?
               QString::fromStdString( "OverallComputationPerformanceTest" ) :
               QString::fromStdString( "MissingOverallComputationPerformanceTest" );
    }

public:
    OverallComputationPerformanceTest(
        ComputationLoadBalanceTest*
        );

    virtual
    ~OverallComputationPerformanceTest()
    {
    };

// ------ overview tests ---------

    bool
    isActive() const
    {
        return
            comp_load_balance->isActive();
    }

    bool
    isIssue() const
    {
        return false;
    }
};
};

#endif // ADVISER_RATING_WIDGET_H
