/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2018                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#ifndef OVERALL_MANAGEMENT_PERFORMANCE_TEST_H
#define OVERALL_MANAGEMENT_PERFORMANCE_TEST_H

#include <string>

#include "AlgMgmtTest.h"
#include "CommunicationTest.h"
#include "GPUOverheadTest.h"
#include "IOOverheadTest.h"
#include "NonComputationLoadBalanceTest.h"
#include "PerformanceTest.h"


namespace advisor
{
class OverallManagementPerformanceTest : public PerformanceTest
{
private:
    AlgMgmtTest*                   alg_mgm;
    CommunicationTest*             communication;
    GPUOverheadTest*               gpu_overhead;
    IOOverheadTest*                io_overhead;
    NonComputationLoadBalanceTest* non_comp_load_balance;

    double alg_mgm_weight;
    double communication_weight;
    double gpu_overhead_weight;
    double io_overhead_weight;
    double non_comp_load_balance_weight;




protected:

    inline
    void
    applyCnode( const cube::list_of_cnodes& cnodes   )
    {
        ( void )cnodes;
        calculateOverall();
    }

    inline
    void
    applyCnode( const cube::Cnode*             cnode,
                const cube::CalculationFlavour cnf = cube::CUBE_CALCULATE_INCLUSIVE  )
    {
        ( void )cnode;
        ( void )cnf;
        calculateOverall();
    }


    void
    calculateOverall();

    virtual
    const std::string&
    getCommentText() const;

    inline
    const
    QString
    getHelpUrl()
    {
        return ( isActive() ) ?
               QString::fromStdString( "OverallManagementPerformanceTest" ) :
               QString::fromStdString( "MissingOverallManagementPerformanceTest" );
    }

public:
    OverallManagementPerformanceTest(
        AlgMgmtTest*,
        CommunicationTest*,
        GPUOverheadTest*,
        IOOverheadTest*,
        NonComputationLoadBalanceTest*
        );

    virtual
    ~OverallManagementPerformanceTest()
    {
    };

// ------ overview tests ---------

    bool
    isActive() const
    {
        return alg_mgm->isActive() ||
               communication->isActive() ||
               gpu_overhead->isActive() ||
               io_overhead->isActive() ||
               non_comp_load_balance->isActive();
    }

    bool
    isIssue() const
    {
        return false;
    }
};
};
#endif // ADVISER_RATING_WIDGET_H
