/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 2015-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/


#include <config.h>

#include "POPNoWaitINSTest.h"


using namespace advisor;

POPNoWaitINSTest::POPNoWaitINSTest( cube::CubeProxy* cube ) : PerformanceTest( cube )
{
    setName( tr( "Instructions (only computation)" ).toUtf8().data() );
    setWeight( 1 );   // need to be adjusted
    no_wait_ins = cube->getMetric( "tot_ins_without_wait" );
    if ( no_wait_ins == NULL )
    {
        setWeight( 0.1 );
        setValue( 0. );
        return;
    }
    cube::list_of_sysresources lsysres = getRootsOfSystemTree();
    cube::metric_pair          metric;
    metric.first  = no_wait_ins;
    metric.second = cube::CUBE_CALCULATE_INCLUSIVE;
    lmetrics.push_back( metric );
}


void
POPNoWaitINSTest::applyCnode( const cube::Cnode* cnode, const cube::CalculationFlavour cnf  )
{
    if ( no_wait_ins == NULL )
    {
        return;
    }

    cube::value_container      inclusive_values;
    cube::value_container      exclusive_values;
    cube::list_of_sysresources lsysres;
    cube::IdIndexMap           metric_id_indices;
    cube->getCallpathSubtreeValues( lmetrics,
                                    lsysres,
                                    *( const_cast<cube::Cnode*>( cnode ) ),
                                    0,
                                    metric_id_indices,
                                    &inclusive_values,
                                    &exclusive_values );
    double no_wait_ins_value = ( cnf == cube::CUBE_CALCULATE_INCLUSIVE ) ?
                               inclusive_values[ 0 ]->getDouble() :
                               exclusive_values[ 0 ]->getDouble();
    setValue( no_wait_ins_value );
}

void
POPNoWaitINSTest::applyCnode( const cube::list_of_cnodes& cnodes )
{
    if ( no_wait_ins == NULL )
    {
        return;
    }
    cube::value_container      inclusive_values;
    cube::value_container      exclusive_values;
    cube::list_of_sysresources lsysres;
    cube::IdIndexMap           metric_id_indices;
    cube->getMetricSubtreeValues( cnodes,
                                  lsysres,
                                  *no_wait_ins,
                                  0,
                                  metric_id_indices,
                                  &inclusive_values,
                                  &exclusive_values );
    double no_wait_ins_value = inclusive_values[ 0 ]->getDouble();
    setValue( no_wait_ins_value );
}

const std::string&
POPNoWaitINSTest::getCommentText() const
{
    if ( no_wait_ins == NULL )
    {
        return no_comment;
    }
    else
    {
        return no_comment;
    }
}


// ------ overview tests ---------

bool
POPNoWaitINSTest::isActive() const
{
    return no_wait_ins != NULL;
};

bool
POPNoWaitINSTest::isIssue() const
{
    return false;
};



void
POPNoWaitINSTest::adjustForTest( cube::CubeProxy* cube ) const
{
    ( void )cube;
}
