/****************************************************************************
**  CUBE        http://www.scalasca.org/                                   **
*****************************************************************************
**  Copyright (c) 1998-2020                                                **
**  Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre          **
**                                                                         **
**  This software may be modified and distributed under the terms of       **
**  a BSD-style license.  See the COPYING file in the package base         **
**  directory for details.                                                 **
****************************************************************************/



#include "config.h"
#include <iostream>

using namespace std;

#include <QtGui>
#include "PythonSyntaxHighlighter.h"

PythonSyntaxHighlighter::PythonSyntaxHighlighter( QTextDocument* parent )
    : QSyntaxHighlighter( parent )
{
    HighlightingRule rule;

    setCurrentBlockState( 0 );

    // quotation
    quotationFormat.setForeground( Qt::darkRed );
    quotationFormat.setFontItalic( true );
    rule.pattern = QRegExp( "\".*\"" );
    rule.format  = quotationFormat;
    highlightingRules.append( rule );

    // beginning of a function
    functionFormat.setFontItalic( true );
    functionFormat.setForeground( Qt::blue );
    rule.pattern = QRegExp( "\\b[A-Za-z0-9_]+(?=\\()" );
    rule.format  = functionFormat;
    highlightingRules.append( rule );

    // all python keywords
    keywordFormat.setForeground( Qt::darkBlue );
    keywordFormat.setFontWeight( QFont::Bold );

    QStringList keywordPatterns;
    keywordPatterns << "\\band\\b" << "\\bdel\\b" << "\\bfrom\\b" << "\\bnot\\b" << "\\bwhile\\b"
                    << "\\bas\\b" << "\\belif\\b" << "\\bglobal\\b" << "\\bor\\b" << "\\bwith\\b"
                    << "\\bassert\\b" << "\\belse\\b" << "\\bif\\b" << "\\bpass\\b" << "\\byield\\b"
                    << "\\bbreak\\b" << "\\bexcept\\b" << "\\bimport\\b" << "\\bprint\\b"
                    << "\\bclass\\b" << "\\bexec\\b" << "\\bin\\b" << "\\braise\\b"
                    << "\\bcontinue\\b" << "\\bfinally\\b" << "\\bis\\b" << "\\breturn\\b"
                    << "\\bdef\\b" << "\\bfor\\b" << "\\blambda\\b" << "\\btry\\b";

    foreach( const QString &pattern, keywordPatterns )
    {
        rule.pattern = QRegExp( pattern, Qt::CaseInsensitive    );
        rule.format  = keywordFormat;
        highlightingRules.append( rule );
    }

    // comments
    singleLineCommentFormat.setForeground( Qt::lightGray );
    singleLineCommentExpression = QRegExp( "#[^\n]*" );
}

void
PythonSyntaxHighlighter::highlightBlock( const QString& text )
{
    int commentLength;
    int startIndex = -1;
    startIndex = singleLineCommentExpression.indexIn( text );
    if ( startIndex >= 0 )
    {
        commentLength = text.length() - startIndex;
        setFormat( startIndex, commentLength, singleLineCommentFormat );
    }
    else
    {
        foreach( const HighlightingRule &rule, highlightingRules )
        {
            QRegExp expression( rule.pattern );
            int     index = expression.indexIn( text );
            while ( index >= 0 )
            {
                int length = expression.matchedLength();
                setFormat( index, length, rule.format );
                index = expression.indexIn( text, index + length );
            }
        }
        setCurrentBlockState( 0 );
    }
}
